//
//  InspectorWindowController.m
//  Shogiban2
//
//  Created by KOYAMA Yoshiaki on Sun Aug 10 2003.
//  Copyright (c) 2003 KOYAMA Yoshiaki. All rights reserved.
//

#import "InspectorWindowController.h"
#import "ShogibanWindowController.h"
#import "YKifController.h"

NSString *SBRotateStepChangeNotification = @"SBRotateStepChange";
NSString *SBFrontStepChangeNotification = @"SBFrontStepChange";
NSString *SBBackStepChangeNotification = @"SBBackStepChange";
NSString *SBFrontStep2ChangeNotification = @"SBFrontStep2Change";
NSString *SBBackStep2ChangeNotification = @"SBBackStep2Change";
NSString *SBInspectorChangeNotification = @"SBInspectorChange";

@implementation InspectorWindowController

+ (id)sharedInspectorController {
    static InspectorWindowController *_sharedInspectorController = nil;
    
    if (!_sharedInspectorController) {
        _sharedInspectorController = [[InspectorWindowController alloc] init]; 
    }

    return _sharedInspectorController;
}

- (id)init {
    self = [self initWithWindowNibName:@"Inspector"];
    if (self) {
        [self setWindowFrameAutosaveName:@"Inspector"];
    }
    return self;
}

- (void)dealloc {
    [[NSNotificationCenter defaultCenter] removeObserver:self];
    [super dealloc];
}

- (void)windowDidLoad {
    NSFont *aFont;
  
    aFont = [NSFont fontWithName:@"HiraKakuPro-W3" size:10];
    [_senteTextField setFont:aFont];
    [_goteTextField setFont:aFont];
 
    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(mainWindowChanged:) name:NSWindowDidBecomeMainNotification object:nil];

    [[NSNotificationCenter defaultCenter] addObserver:self selector:@selector(inspectorChanged:) name:SBInspectorChangeNotification     object:nil];

}

- (void)inspectorChanged:(NSNotification *)notification {
    YKifController *ykifController;
    NSString *str, *format;
    int index, max;

    ykifController = [notification object];
    
    str = [ykifController gameSenteName];
    if (str == nil) {
        [_senteTextField setStringValue:@""];
    } else {
        [_senteTextField setStringValue:str];
    }

    str = [ykifController gameGoteName];
    if (str == nil) {
        [_goteTextField setStringValue:@""];
    } else {
        [_goteTextField setStringValue:str];
    }

    str = [ykifController gameDate];
    if (str == nil) {
        [_dateLabel setStringValue:@""];
    } else {
        [_dateLabel setStringValue:str];
    }

    index = [ykifController indexKif];
    max = [ykifController kifArrayMax];
    if (index == 0) {
        format = NSLocalizedString(@"SOUTESUU",@"%d");
        str = [NSString stringWithFormat:format, max/4];        
    } else {
        format = NSLocalizedString(@"TESUU",@"%d");
        str = [NSString stringWithFormat:format, index/4, max/4];
    }
    [_tesuuLabel setStringValue:str];

}

- (void)mainWindowChanged:(NSNotification *)notification {
    ShogibanWindowController *controller = [[notification object] windowController];
    NSDocument *document;
    NSString *title;

    if (controller && [controller isKindOfClass:[ShogibanWindowController class]]) {
        document = [controller document];
        title = [document displayName];
    }
}

- (IBAction)selectRotateStepAction:(id)sender {
   [[NSNotificationCenter defaultCenter] postNotificationName:SBRotateStepChangeNotification object:self];
}

- (IBAction)selectFrontStepAction:(id)sender {
   [[NSNotificationCenter defaultCenter] postNotificationName:SBFrontStepChangeNotification object:self];
}

- (IBAction)selectBackStepAction:(id)sender {
   [[NSNotificationCenter defaultCenter] postNotificationName:SBBackStepChangeNotification object:self];
}

- (IBAction)selectFrontStep2Action:(id)sender {
   [[NSNotificationCenter defaultCenter] postNotificationName:SBFrontStep2ChangeNotification object:self];
}

- (IBAction)selectBackStep2Action:(id)sender {
   [[NSNotificationCenter defaultCenter] postNotificationName:SBBackStep2ChangeNotification object:self];
}

@end
